BluetoothLowEnergyRecord class

A NDEF record for Bluetooth Low Energy out-of-band pairing.

Contains Bluetooth LE device information for pairing.

Inheritance

Constructors

BluetoothLowEnergyRecord({Map<EIRType, Uint8List>? attributes})
Constructs a BluetoothLowEnergyRecord with optional attributes.

Properties

address LEAddress?
Gets the Bluetooth LE device address.
getter/setter pair
appearance String?
getter/setter pair
attributes Map<EIRType?, Uint8List>
Map of EIR type to data attributes.
getter/setter pairinherited
basicInfoString String
Gets a basic information string containing ID, TNF, and type.
no setterinherited
decodedType String
Gets the type as a decoded UTF-8 string.
getter/setter pairinherited-setteroverride-getter
deviceName String
Gets the Bluetooth device name.
getter/setter pairinherited
encodedType Uint8List?
The raw encoded type bytes.
getter/setter pairinherited
flags NDEFRecordFlags
The flags header of the record.
getter/setter pairinherited
flagsEIR List<String>?
getter/setter pair
fullType String?
Gets the full qualified type including TNF prefix.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id Uint8List?
The ID of the record (optional).
getter/setter pairinherited
idString String
Hex String of id, return "(empty)" when the id bytes is null
getter/setter pairinherited
leSecureConnectionsConfirmationValue BigInt
getter/setter pair
leSecureConnectionsRandomValue BigInt
getter/setter pair
maxPayloadLength int?
Gets the maximum payload length for this record instance.
no setterinherited
minPayloadLength int
Gets the minimum payload length for this record instance.
no setterinherited
payload Uint8List?
The payload data of the record.
getter/setter pairoverride
roleCapabilities String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityManagerTKValue BigInt
getter/setter pair
tnf TypeNameFormat
Gets the Type Name Format of this record.
getter/setter pairinherited
type Uint8List?
Gets the type as raw bytes.
getter/setter pairinherited

Methods

encode() Uint8List
Encode this NDEFRecord to raw byte data.
inherited
getAttribute(EIRType type) Uint8List?
Gets the attribute value for the specified EIR type.
inherited
getIntValue(EIRType type) BigInt
Gets an integer value for the specified EIR type.
inherited
isEqual(NDEFRecord other) bool
Checks if this record is equal to other by comparing TNF, type, ID, and payload.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttribute(EIRType? type, Uint8List value) → void
Sets the attribute value for the specified EIR type.
inherited
setIntValue(EIRType type, BigInt value) → void
Sets an integer value for the specified EIR type.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

appearanceMap → const Map<int, String>
classType → const String
The MIME type for Bluetooth Low Energy records.
flagsList → const List<String>
leRoleList → const List<String>