LEAddress class

Bluetooth Low Energy address with type.

Constructors

LEAddress({LEAddressType? type, String? address})
Constructs an LEAddress with the specified type and address.
LEAddress.fromBytes(Uint8List? bytes)
LEAddress.fromTypeBytes(LEAddressType? type, Uint8List bytes)

Properties

addr ↔ Uint8List
getter/setter pairinherited
address ↔ String
getter/setter pairinherited
bytes ↔ Uint8List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ LEAddressType
The address type (public or random).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited