ServiceClass class

Constructors

ServiceClass({required Uint8List uuidData})
uuidData is non nullable, so use required keyword here.

Properties

bytes ↔ Uint8List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name → String?
UUID name if supported or UUID
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String
no setter
uuidData ↔ Uint8List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

baseUuid → const String
uuidNameMap → const Map<int, String>