DataElement class

A data element in a Device Information record.

Consists of a type identifier and a value.

Constructors

DataElement(int type, Uint8List value)
Constructs a DataElement with type and value.
DataElement.fromString(int type, String valueString)
Constructs a DataElement with type and valueString encoded as UTF-8.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
The type identifier of the data element.
getter/setter pair
value Uint8List
The value of the data element as bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited