AlternativeCarrierRecord class
A NDEF record describing an alternative carrier for connection handover.
This record identifies a carrier technology and its power state.
- Inheritance
-
- Object
- NDEFRecord
- WellKnownRecord
- AlternativeCarrierRecord
Constructors
-
AlternativeCarrierRecord({CarrierPowerState? carrierPowerState, Uint8List? carrierDataReference, List<
Uint8List> ? auxDataReferenceList}) - Constructs an AlternativeCarrierRecord with carrier information.
Properties
-
auxDataReferenceList
↔ List<
Uint8List> -
List of auxiliary data references.
getter/setter pair
- basicInfoString → String
-
Gets a basic information string containing ID, TNF, and type.
no setterinherited
- carrierDataReference ↔ Uint8List
-
Reference to the carrier data record.
getter/setter pair
- carrierPowerState ↔ CarrierPowerState
-
The power state of the carrier.
getter/setter pair
- carrierPowerStateIndex ↔ int
-
Gets the carrier power state as an index.
getter/setter pair
- decodedType ↔ String
-
Gets the type as a decoded UTF-8 string.
getter/setter pairinherited-setteroverride-getter
- encodedType ↔ Uint8List?
-
The raw encoded type bytes.
getter/setter pairinherited
- flags ↔ NDEFRecordFlags
-
The flags header of the record.
getter/setter pairinherited
- fullType → String?
-
Gets the full qualified type including TNF prefix.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ Uint8List?
-
The ID of the record (optional).
getter/setter pairinherited
- idString ↔ String
-
Hex String of id, return "(empty)" when the id bytes is null
getter/setter pairinherited
- maxPayloadLength → int?
-
Gets the maximum payload length for this record instance.
no setterinherited
- minPayloadLength → int
-
Gets the minimum payload length for this record instance.
no setteroverride
- payload ↔ Uint8List
-
The payload data of the record.
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tnf ↔ TypeNameFormat
-
Gets the Type Name Format of this record.
getter/setter pairinherited
- type ↔ Uint8List?
-
Gets the type as raw bytes.
getter/setter pairinherited
Methods
-
encode(
) → Uint8List -
Encode this NDEFRecord to raw byte data.
inherited
-
isEqual(
NDEFRecord other) → bool -
Checks if this record is equal to
otherby comparing TNF, type, ID, and payload.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- classMinPayloadLength → const int
- The minimum payload length for Alternative Carrier records.
- classType → const String
- The type identifier for Alternative Carrier records.