TextRecord class

A NDEF record containing text with language code.

This record stores text content along with its encoding (UTF-8 or UTF-16) and a language code (e.g., "en" for English).

Inheritance

Constructors

TextRecord({TextEncoding encoding = TextEncoding.UTF8, String? language, String? text})
Constructs a TextRecord with optional encoding, language, and text.

Properties

basicInfoString → String
Gets a basic information string containing ID, TNF, and type.
no setterinherited
decodedType ↔ String
Gets the type as a decoded UTF-8 string.
getter/setter pairinherited-setteroverride-getter
encodedType ↔ Uint8List?
The raw encoded type bytes.
getter/setter pairinherited
encoding ↔ TextEncoding
The text encoding type.
getter/setter pair
encodingString → String
Gets the encoding as a readable string.
no setter
flags ↔ NDEFRecordFlags
The flags header of the record.
getter/setter pairinherited
fullType → String?
Gets the full qualified type including TNF prefix.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ Uint8List?
The ID of the record (optional).
getter/setter pairinherited
idString ↔ String
Hex String of id, return "(empty)" when the id bytes is null
getter/setter pairinherited
language ↔ String?
Gets the language code.
getter/setter pair
maxPayloadLength → int?
Gets the maximum payload length for this record instance.
no setterinherited
minPayloadLength → int
Gets the minimum payload length for this record instance.
no setteroverride
payload ↔ Uint8List
The payload data of the record.
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The text content.
getter/setter pair
tnf ↔ TypeNameFormat
Gets the Type Name Format of this record.
getter/setter pairinherited
type ↔ Uint8List?
Gets the type as raw bytes.
getter/setter pairinherited

Methods

encode() → Uint8List
Encode this NDEFRecord to raw byte data.
inherited
isEqual(NDEFRecord other) → bool
Checks if this record is equal to other by comparing TNF, type, ID, and payload.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

classMinPayloadLength → const int
classType → const String
The type identifier for Text records.