UriRecord class
A NDEF record containing a URI (Uniform Resource Identifier).
This record uses a prefix compression scheme to reduce the size of common URI prefixes.
- Inheritance
-
- Object
- NDEFRecord
- WellKnownRecord
- UriRecord
Constructors
Properties
- basicInfoString → String
-
Gets a basic information string containing ID, TNF, and type.
no setterinherited
- content ↔ String?
-
The URI content after the prefix.
getter/setter pair
- decodedType ↔ String
-
Gets the type as a decoded UTF-8 string.
getter/setter pairinherited-setteroverride-getter
- encodedType ↔ Uint8List?
-
The raw encoded type bytes.
getter/setter pairinherited
- flags ↔ NDEFRecordFlags
-
The flags header of the record.
getter/setter pairinherited
- fullType → String?
-
Gets the full qualified type including TNF prefix.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ Uint8List?
-
The ID of the record (optional).
getter/setter pairinherited
- idString ↔ String
-
Hex String of id, return "(empty)" when the id bytes is null
getter/setter pairinherited
- iriString ↔ String?
-
Gets the full IRI (Internationalized Resource Identifier) string.
getter/setter pair
- maxPayloadLength → int?
-
Gets the maximum payload length for this record instance.
no setterinherited
- minPayloadLength → int
-
Gets the minimum payload length for this record instance.
no setteroverride
- payload ↔ Uint8List?
-
Encode and Get payload, return null when the prefix or content is null
getter/setter pairoverride
- prefix ↔ String?
-
Gets the URI prefix from the prefix map.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tnf ↔ TypeNameFormat
-
Gets the Type Name Format of this record.
getter/setter pairinherited
- type ↔ Uint8List?
-
Gets the type as raw bytes.
getter/setter pairinherited
- uri ↔ Uri?
-
Gets the URI as a Uri instance.
getter/setter pair
- uriString ↔ String?
-
Gets the full URI string.
getter/setter pair
Methods
-
encode(
) → Uint8List -
Encode this NDEFRecord to raw byte data.
inherited
-
isEqual(
NDEFRecord other) → bool -
Checks if this record is equal to
otherby comparing TNF, type, ID, and payload.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- classMinPayloadLength → const int
- The minimum payload length for URI records.
- classType → const String
- The type identifier for URI records.